use Test::Mojo;
use Test::More;
use File::Path 'remove_tree';

{
  use Mojolicious::Lite;
  mkdir app->static->paths->[0];
  get "/" => "index";
  app->plugin("riotjs");
  app->asset(
    "app.js" => qw(
      http://cdnjs.cloudflare.com/ajax/libs/riot/2.0.13/riot.js
      /js/todo.tag
      /js/main.js
      )
  );
  return app->start if $ENV{RUN_APP};
}

my $t = Test::Mojo->new;
plan skip_all => 'npm install riot' unless $t->app->asset->preprocessors->can_process('tag');
$t->get_ok('/')->status_is(200)->element_exists('script')->text_like('script', qr{riot\.tag\('todo',})
  ->text_like('script', qr{riot\.mount\('todo'\)});

remove_tree($t->app->static->paths->[0]);
done_testing;

__DATA__
@@ js/todo.tag
<todo>
  <h3>{ opts.title }</h3>
  <ul>
    <li each={ item, i in items }>{ item.title }</li>
  </ul>
  <form onsubmit={ add }>
    <input>
    <button>Add #{ items.length + 1 }</button>
  </form>

  this.items = []

  add(e) {
    var input = e.target[0]
    if (input.value.length) this.items.push({ title: input.value })
    input.value = ''
  }
</todo>

@@ js/main.js
riot.mount('todo')

@@ index.html.ep
<!DOCTYPE html>
<html>
  <head>
    <title>Riot.js Demo</title>
    <!--[if lt IE 9]>
    <script src="//cdnjs.cloudflare.com/ajax/libs/es5-shim/4.0.5/es5-shim.min.js"></script>
    <script src="//cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.2/html5shiv.min.js"></script>
    <script>html5.addElements('todo')</script>
    <![endif]-->
  </head>
  <body>
    <todo></todo>
    %= asset "app.js" => { inline => 1 };
  </body>
</html>
